@@ -6,6 +6,14 @@ use 5.010; # [sic - pluggable regex engines]
 use strict;
 use warnings;
 
+our $VERSION = "0.001";
+
+#############################################################
+#                                                           #
+# Benchmark Code ahead - Don't touch without strong reason! #
+#                                                           #
+#############################################################
+
 use Benchmark ':hireswallclock';
 use Data::Dumper;
 
@@ -39,10 +47,12 @@ sub POSIX
         my ($options) = @_;
 
         my $reg;
+        ## no critic
         eval '
                 use POSIX::Regex qw(:all);
                 $reg = POSIX::Regex->new($re, REG_EXTENDED);
         ';
+        ## use critic
         if ($@) {
                 print STDERR "# ".$@ if $options->{verbose} > 2;
                 return { failed => "use failed" };
@@ -69,7 +79,7 @@ sub LPeg
         # LPEG regexes seemingly don't work the same way as usual regexes
         # therefore the pattern below does not match.
         # TODO: Find a equivalent pattern.
-        eval "use re::engine::LPEG";
+        eval "use re::engine::LPEG"; ## no critic
         if ($@) {
                 print STDERR "# ".$@ if $options->{verbose} > 2;
                 return { failed => "use failed" };
@@ -101,7 +111,7 @@ sub Lua
         # TODO: Find a equivalent pattern.
         # return { not_yet_implemented => 'need to find a equivalent pattern' };
 
-        eval "use re::engine::Lua";
+        eval "use re::engine::Lua"; ## no critic
         if ($@) {
                 print STDERR "# ".$@ if $options->{verbose} > 2;
                 return { failed => "use failed" };
@@ -125,7 +135,31 @@ sub PCRE
 {
         my ($options) = @_;
 
-        eval "use re::engine::PCRE";
+        eval "use re::engine::PCRE"; ## no critic
+        if ($@) {
+                print STDERR "# ".$@ if $options->{verbose} > 2;
+                return { failed => "use failed" };
+        }
+
+        my $result;
+        my $reg = qr/$re/o;
+        my $t = timeit $count, sub { $result = $string =~ $reg };
+        return {
+                Benchmark => $t,
+                goal      => $goal,
+                count     => $count,
+                result    => $result,
+                # string    => $string,
+                # re        => $re_local,
+                used_qr_or_precompile => 1,
+               };
+}
+
+sub RE2
+{
+        my ($options) = @_;
+
+        eval "use re::engine::RE2"; ## no critic
         if ($@) {
                 print STDERR "# ".$@ if $options->{verbose} > 2;
                 return { failed => "use failed" };
@@ -149,7 +183,7 @@ sub Plan9
 {
         my ($options) = @_;
 
-        eval "use re::engine::Plan9";
+        eval "use re::engine::Plan9"; ## no critic
         if ($@) {
                 print STDERR "# ".$@ if $options->{verbose} > 2;
                 return { failed => "use failed" };
@@ -173,7 +207,7 @@ sub Oniguruma
 {
         my ($options) = @_;
 
-        eval "use re::engine::Oniguruma";
+        eval "use re::engine::Oniguruma"; ## no critic
         if ($@) {
                 print STDERR "# ".$@ if $options->{verbose} > 2;
                 return { failed => "use failed" };
@@ -201,8 +235,8 @@ sub regexes
 
         my %results = ();
 
-        no strict "refs";
-        for my $subtest (qw( native POSIX Lua LPeg PCRE Oniguruma Plan9 )) {
+        no strict "refs"; ## no critic
+        for my $subtest (qw( native POSIX Lua LPeg PCRE RE2 Oniguruma Plan9 )) {
                 print STDERR "#  - $subtest...\n" if $options->{verbose} > 2;
                 $results{$subtest} = $subtest->($options);
         }
