@@ -14,8 +14,17 @@ package Benchmark::Perl::Formance::Plugin::Shootout::knucleotide;
 # Benchmark::Perl::Formance plugin by Steffen Schwigon
 
 use strict;
+use warnings;
 use threads;
 
+our $VERSION = "0.001";
+
+#############################################################
+#                                                           #
+# Benchmark Code ahead - Don't touch without strong reason! #
+#                                                           #
+#############################################################
+
 use Benchmark::Perl::Formance::Cargo;
 use File::ShareDir qw(module_dir);
 use Benchmark ':hireswallclock';
@@ -36,12 +45,12 @@ sub run
 
         my $srcdir = module_dir('Benchmark::Perl::Formance::Cargo')."/Shootout";
         my $srcfile = "$srcdir/$infile";
-        open INFILE, "<", $srcfile or die "Cannot read $srcfile";
+        open my $INFILE, "<", $srcfile or die "Cannot read $srcfile";
 
         $/ = ">";
-        /^THREE/ and $sequence = uc(join "", grep !/^THREE/, split /\n+/) while <INFILE>;
+        /^THREE/ and $sequence = uc(join "", grep !/^THREE/, split /\n+/) while <$INFILE>;
 
-        close INFILE;
+        close $INFILE;
 
         ($l,%h,$sum) = (length $sequence);
 
@@ -88,7 +97,7 @@ sub update_hash_slice {
 }
 
 sub num_cpus {
-  open my $fh, '</proc/cpuinfo' or return;
+  open my $fh, '<', '/proc/cpuinfo' or return;
   my $cpus;
   while (<$fh>) {
           $cpus ++ if /^processor[\s]+:/; # 0][]0]; # for emacs cperl-mode indent bug
