@@ -13,6 +13,14 @@ use strict;
 use Math::GMP;
 use Benchmark ':hireswallclock';
 
+our $VERSION = "0.001";
+
+#############################################################
+#                                                           #
+# Benchmark Code ahead - Don't touch without strong reason! #
+#                                                           #
+#############################################################
+
 my($z0, $z1, $z2);
 
 sub extract_digit { return ($z0*$_[0]+$z1)/$z2; }
@@ -39,7 +47,7 @@ sub run
         my ($i, $s, $d); my $k = 0;
 
         # main loop
-        for $i (1..$n) {
+        for $i (1..$n) { ## no critic
                 while (
                        $z0>$z2 || ( $d = extract_digit(3) ) != extract_digit(4)
                       ) {
